@@ -12,7 +12,7 @@ if (.runThisTest && require("testthat") && require("brms")) {
     expect_s3_class(summary(r), "character")
     expect_s3_class(as.data.frame(r), "data.frame")
 
-    expect_snapshot(report(model))
+    expect_snapshot(variant = .Platform$OS.type, report(model))
 
     expect_equal(
       as.data.frame(r)$Parameter,
